For testing a PHiLIP device must be flashed and connected with the `DUT_RST` pin connected to the `DEBUG0` pin and pullup the to 3.3V.
Then run the regular test commands `python3 setup.py test` to initiate the tests.

_Good luck_
